@@ -5,7 +5,7 @@ from types import TupleType, UnicodeType, StringType
 import urlparse
 
 from Products.CMFPlone.utils import safe_callable
-from Products.CMFPlone.utils import safe_hasattr
+from Products.CMFPlone.utils import base_hasattr
 from Products.CMFPlone.utils import log
 from Products.CMFPlone.utils import log_exc
 from Products.CMFPlone import transaction
@@ -19,7 +19,7 @@ from Products.CMFCore.utils import UniqueObject
 from Products.CMFCore.utils import _checkPermission, \
      _getAuthenticatedUser, limitGrantedRoles
 from Products.CMFCore.utils import getToolByName, _dtmldir
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore import permissions as CMFCorePermissions
 from Products.CMFCore.permissions import AccessContentsInformation
 from Products.CMFCore.interfaces.DublinCore import DublinCore, MutableDublinCore
 from Products.CMFCore.interfaces.Discussions import Discussable
@@ -55,6 +55,11 @@ FLOOR_DATE = DefaultDublinCoreImpl._DefaultDublinCoreImpl__FLOOR_DATE
 from Products.SecureMailHost.SecureMailHost import EMAIL_RE
 from Products.SecureMailHost.SecureMailHost import EMAIL_CUTOFF_RE
 BAD_CHARS = re.compile(r'[^a-zA-Z0-9-_~,.$\(\)# ]').findall
+# Define and compile static regexes
+FILENAME_REGEX = re.compile(r"^(.+)\.(\w{,4})$")
+NON_WORD_REGEX = re.compile(r"[\W\-]+")
+EXTRA_DASHES_REGEX = re.compile(r"(^\-+)|(\-+$)")
+
 
 # XXX Remove this when we don't depend on python2.1 any longer,
 # use email.Utils.getaddresses instead
@@ -1228,21 +1233,20 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         if not isinstance(text, unicode):
             text = unicode(text, self.getSiteEncoding())
 
-        text = text.lower()
         text = text.strip()
+        text = text.lower()
         text = normalizeUnicode(text)
 
         base = text
         ext  = ""
 
-        m = re.match(r"^(.+)\.(\w{,4})$", text)
+        m = FILENAME_REGEX.match(text)
         if m is not None:
             base = m.groups()[0]
             ext  = m.groups()[1]
 
-        base = re.sub(r"[\W\-]+", "-", base)
-        base = re.sub(r"^\-+",    "",  base)
-        base = re.sub(r"\-+$",    "",  base)
+        base = NON_WORD_REGEX.sub("-", base)
+        base = EXTRA_DASHES_REGEX.sub("", base)
 
         if ext != "":
             base = base + "." + ext
@@ -1421,14 +1425,15 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
                                      default=empty)
         return empty
 
+    security.declarePublic('pretty_title_or_id')
     def pretty_title_or_id(self, obj, empty_value=_marker):
         """Return the best possible title or id of an item, regardless
         of whether obj is a catalog brain or an object, but returning an
         empty title marker if the id is not set (i.e. it's auto-generated).
         """
-        if safe_hasattr(obj, 'aq_explicit'):
-            obj = obj.aq_explicit
-        title = getattr(obj, 'Title', None)
+        title = None
+        if base_hasattr(obj, 'Title'):
+            title = getattr(obj, 'Title', None)
         if safe_callable(title):
             title = title()
         if title:
@@ -1442,6 +1447,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
             empty_value = self.getEmptyTitle()
         return empty_value
 
+    security.declarePublic('getMethodAliases')
     def getMethodAliases(self, typeInfo):
         """Given an FTI, return the dict of method aliases defined on that
         FTI. If there are no method aliases (i.e. this FTI doesn't support it),
