@@ -25,10 +25,10 @@ from Products.CMFPlone import cmfplone_globals
 from Products.CMFQuickInstallerTool import QuickInstallerTool, AlreadyInstalled
 from Products.CMFPlone.setup.ConfigurationMethods import addSiteProperties
 from Products.CMFPlone.migrations.migration_util import safeEditProperty
-from Products.CMFPlone import ToolNames
+from Products.CMFPlone import ToolNames, transaction
 
 from Products.CMFCore import CachingPolicyManager
-from Products.CMFCore.CMFCorePermissions import ListFolderContents, SetOwnProperties, SetOwnPassword
+from Products.CMFCore.permissions import ListFolderContents, SetOwnProperties, SetOwnPassword
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.TypesTool import FactoryTypeInformation
 from ZODB.POSException import ConflictError
@@ -39,11 +39,11 @@ def make_plone(portal):
     folder_wf = wf_tool['folder_workflow']
     folder_wf.states.visible.permission_roles[ListFolderContents]=('Manager', 'Owner', 'Member')
 
-    addPortalFormValidators(portal)
+    #addPortalFormValidators(portal)    # Gone since 2.1
     addCatalogIndexes(portal)
     addCatalogLexicon(portal)
     addSiteProperties(portal,portal)
-    addNavigationProperties(portal)
+    #addNavigationProperties(portal)    # Gone since 2.1
     extendSiteProperties(portal)
     extendMemberdata(portal)
     addDefaultPloneSkins(portal)
@@ -204,7 +204,7 @@ def addGroupUserFolder(portal):
         NOTE: In the Install routine for GRUF it does a subtransaction commit()
         so that you can manipulate the acl_users folders.
     """
-    get_transaction().commit(1)
+    transaction.commit(1)
     out=[]
     out.append('Adding GroupUserFolder to portal')
     qi=getToolByName(portal, 'portal_quickinstaller')
@@ -225,7 +225,7 @@ def addDocumentActions(portal):
     at.addAction('extedit',
                  'Edit this file in an external application (Requires Zope ExternalEditor installed)',
                  'string:$object_url/external_edit',
-                 "python: hasattr(portal.portal_properties.site_properties, 'ext_editor') and portal.portal_properties.site_properties.ext_editor and object.absolute_url() != portal_url",
+                 "python: member and hasattr(member, 'ext_editor') and member.ext_editor and object.absolute_url() != portal_url",
                  'Modify portal content',
                  'document_actions')
 
@@ -253,9 +253,10 @@ def addDocumentActions(portal):
     at.addAction('addtofavorites',
                  'Add to Favorites',
                  'string:${object_url}/addtoFavorites',
-                 'member',
+                 'python: member and portal.portal_membership.getHomeFolder() is not None',
                  'View',
-                 'document_actions')
+                 'document_actions',
+                 visible=0)
 
 
 def upgradePortalFactory(portal):
@@ -401,7 +402,7 @@ def addActionIcons(portal):
     ai.addActionIcon('plone', 'print', 'print_icon.gif', 'Print')
     ai.addActionIcon('plone', 'rss', 'rss.gif', 'Syndication')
     ai.addActionIcon('plone', 'extedit', 'extedit_icon.gif', 'ExternalEdit')
-    ai.addActionIcon('plone', 'addtofavorites', 'site_icon.gif', 'AddToFavorites')
+    ai.addActionIcon('plone', 'addtofavorites', 'favorite_icon.gif', 'AddToFavorites')
     qi=getToolByName(portal, 'portal_quickinstaller')
     qi.notifyInstalled('CMFActionIcons')
 
@@ -422,7 +423,7 @@ def makePortalRootPortalType(portal):
     portal.portal_workflow._chains_by_type['Plone Site']=()
     sprops=portal.portal_properties.site_properties
     use_folder_tabs=sprops.getProperty('use_folder_tabs')
-    sprops._updateProperty('use_folder_tabs', use_folder_tabs+('Plone Site',))
+    sprops._updateProperty('use_folder_tabs', tuple(use_folder_tabs)+('Plone Site',))
 
     #By default Members do not have List folder contents to the root.  I believe this
     # happenes because it starts out with a Folder's workflow.  We could fix this.
